@@ -1,3 +1,5 @@
+use crate::prelude::mutations_helpers::insert_valid_integrated_op;
+
 use super::*;
 
 #[tokio::test(flavor = "multi_thread")]
@@ -10,20 +12,8 @@ async fn link_queries_are_ordered_by_timestamp() {
         .unwrap();
 
     let td = LinkTestData::new();
-    insert_op(&mut txn, td.create_link_op.clone(), true).unwrap();
-    set_validation_status(
-        &mut txn,
-        td.create_link_op.as_hash().clone(),
-        ValidationStatus::Valid,
-    )
-    .unwrap();
-    insert_op(&mut txn, td.later_create_link_op.clone(), true).unwrap();
-    set_validation_status(
-        &mut txn,
-        td.later_create_link_op.as_hash().clone(),
-        ValidationStatus::Valid,
-    )
-    .unwrap();
+    insert_valid_integrated_op(&mut txn, td.create_link_op.clone()).unwrap();
+    insert_valid_integrated_op(&mut txn, td.later_create_link_op.clone()).unwrap();
     let links = td.tag_query.run(Txn::from(&txn)).unwrap();
     assert_eq!(links, vec![td.link.clone(), td.later_link.clone()]);
     let links = td.details_tag_query.run(Txn::from(&txn)).unwrap();
