@@ -20,7 +20,7 @@ async fn exists() {
         ChainTopOrdering::default(),
     )
     .unwrap();
-    insert_op(&mut txn, td.store_entry_op.clone(), true).unwrap();
+    insert_op(&mut txn, td.store_entry_op.clone()).unwrap();
     assert!(Txn::from(&txn)
         .contains_hash(&td.hash.clone().into())
         .unwrap());
